@@ -5,9 +5,8 @@ from gi.repository import GLib, Gtk, GObject, Gdk, XApp
 import gettext
 APP = 'mintinstall'
 LOCALE_DIR = "/usr/share/linuxmint/locale"
-gettext.bindtextdomain(APP, LOCALE_DIR)
-gettext.textdomain(APP)
-_ = gettext.gettext
+t = gettext.translation(APP, LOCALE_DIR, fallback=True)
+_ = t.gettext
 
 from aptdaemon.gtk3widgets import AptConfirmDialog
 
